==> guvnor-webapp-drools-5.4.0.Beta1-sources.jar: org/drools/guvnor/client/widgets/drools/decoratedgrid/events/DeleteColumnEvent.java <==
/*
 * Copyright 2011 JBoss Inc
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.drools.guvnor.client.widgets.drools.decoratedgrid.events;

import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;

/**
 * An event to delete a column
 */
public class DeleteColumnEvent extends GwtEvent<DeleteColumnEvent.Handler> {

    public static interface Handler
        extends
        EventHandler {

        void onDeleteColumn(DeleteColumnEvent event);
    }

    public static Type<DeleteColumnEvent.Handler> TYPE   = new Type<DeleteColumnEvent.Handler>();

    private int                                   index;

    private boolean                               redraw = true;

    public DeleteColumnEvent(int index) {
        this.index = index;
    }

    public DeleteColumnEvent(int index,
                             boolean redraw) {
        this.index = index;
        this.redraw = redraw;
    }

    public int getIndex() {
        return this.index;
    }

    public boolean redraw() {
        return this.redraw;
    }

    @Override
    public Type<DeleteColumnEvent.Handler> getAssociatedType() {
        return TYPE;
    }

    @Override
    protected void dispatch(DeleteColumnEvent.Handler handler) {
        handler.onDeleteColumn( this );
    }

}

==> guvnor-webapp-drools-5.5.0.Beta1-sources.jar: org/drools/guvnor/client/widgets/drools/decoratedgrid/events/DeleteColumnEvent.java <==
/*
 * Copyright 2011 JBoss Inc
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.drools.guvnor.client.widgets.drools.decoratedgrid.events;

import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;

/**
 * An event to delete a column
 */
public class DeleteColumnEvent extends GwtEvent<DeleteColumnEvent.Handler> {

    public static interface Handler
        extends
        EventHandler {

        void onDeleteColumn(DeleteColumnEvent event);
    }

    public static final Type<DeleteColumnEvent.Handler> TYPE            = new Type<DeleteColumnEvent.Handler>();

    private int                                         firstColumnIndex;
    private int                                         numberOfColumns = 1;
    private boolean                                     redraw          = true;

    public DeleteColumnEvent(int firstColumnIndex) {
        this.firstColumnIndex = firstColumnIndex;
    }

    public DeleteColumnEvent(int firstColumnIndex,
                             boolean redraw) {
        this.firstColumnIndex = firstColumnIndex;
        this.redraw = redraw;
    }

    public DeleteColumnEvent(int firstColumnIndex,
                             int numberOfColumns,
                             boolean redraw) {
        this.firstColumnIndex = firstColumnIndex;
        this.numberOfColumns = numberOfColumns;
        this.redraw = redraw;
    }

    public int getFirstColumnIndex() {
        return this.firstColumnIndex;
    }

    public int getNumberOfColumns() {
        return this.numberOfColumns;
    }

    public boolean redraw() {
        return this.redraw;
    }

    @Override
    public Type<DeleteColumnEvent.Handler> getAssociatedType() {
        return TYPE;
    }

    @Override
    protected void dispatch(DeleteColumnEvent.Handler handler) {
        handler.onDeleteColumn( this );
    }

}
